#! /bin/sh

TESTFILE="testfile.$$"
PRODUCT="ASDK Ver 1.0.3"

####

echo '=================================================================='
echo ''
echo '  Aglets Software Development Kit(ASDK) version 1.0.3 Installation'
echo ''
echo '=================================================================='
echo ''

INSTALL_DIR=$HOME/Aglets1.0.3

if test "`/bin/echo 'zzz\c'`" = "zzz\c"
then
	EFLAG="-n"
	ENDER=""
else
	EFLAG=""
	ENDER="\c"
fi
ECHO="/bin/echo ${EFLAG}"

#
# Even though the user has already used gzip to extract the file (or
# we wouldn't be here), make sure we can find it.
#
UC="/bin/uncompress"
flag=1
while test ${flag} -eq 1
do
	if test ! -x ${UC}
	then
		echo ""
		echo "Failed to find 'uncompress' in your system.  Please provide the fully-qualified"
		echo "directory in which it can be found."
		echo ""
		${ECHO} "Directory containing the 'uncompress' binary: ${ENDER}"
		read UC_DIR
		UC="${UC_DIR}/uncompress"
	else
		flag=0
	fi
done


if test -d /opt
then
	applocal=/opt
else
	applocal=/usr/local
fi

JDK_HOME=/usr/local/jdk1.1

echo ""
echo "Please specify the directory path under which JDK has been installed."
echo "(Sorry, please specify in ABSOLUTE path and don't use ~ )"
echo "The default directory is ${JDK_HOME}."
echo ""
flag=1
while test ${flag} -eq 1
do
	${ECHO} "Location of JDK [${JDK_HOME}]: ${ENDER}"
	read d
	if test -z "${d}"
	then
		d="${JDK_HOME}"
	fi
	flag=0
	if test ! -d ${d}
	then
		echo ""
		${ECHO} "${d}: No such directory."
		${ECHO} "Do you wish to try specifying another one? (y/n)[y] ${ENDER}"
		read check
		if test "${check}" = "n" -o "${check}" = "N"
		then
			echo ""
			${ECHO} "It is highly recommended to install JDK in advance."
			${ECHO} "Proceed anyway? (y/n)[n] ${ENDER}"
			read check
			if test "${check}" = "y" -o "${check}" = "Y"
			then
				echo "Please make sure to install JDK later."
				JDK_HOME=${d}
			else
				echo ""
				flag=1
			fi
		else
			echo ""
			flag=1
		fi
	else
		JDK_HOME=${d}
	fi
done

echo ""
echo "Please specify the directory path under which ASDK will be installed."
echo "(Sorry, please specify in ABSOLUTE path and don't use ~ )"
echo "The default directory is ${INSTALL_DIR}."
echo ""
flag=1
while test ${flag} -eq 1
do
	${ECHO} "Location for ${PRODUCT} [${INSTALL_DIR}]: ${ENDER}"
	read TARGET
	if test -z "${TARGET}"
	then
		TARGET="${INSTALL_DIR}"
	fi
	flag=0
	if test ! -d ${TARGET}
	then
		echo ""
		${ECHO} "${TARGET}: No such directory.  Do you wish to create it? (y/n)[y] ${ENDER}"
		read check
		if test "${check}" = "n" -o "${check}" = "N"
		then
			flag=1
		else
			mkdir -p ${TARGET}
			if test $? -ne 0
			then
				echo "ERROR: Problem creating ${TARGET}"
				exit 2
			fi
		fi
	else
		echo ""
		echo "Existing '${TARGET}' directory found."
		echo ""
		echo "The existing contents may be modified or replaced if you install in"
		echo "this directory.  If you choose not to install in '${TARGET}',"
		echo "you will be prompted for a different directory."
		echo ""
		${ECHO} "Do you wish to continue with the installation in '${TARGET}'? (y/n)[y] ${ENDER}"
		read check
		if test "${check}" = "n" -o "${check}" = "N"
		then
			flag=1
		fi
	fi

	if test ${flag} -eq 0
	then
		(echo "$0: Write test." 2>/dev/null > ${TARGET}/${TESTFILE}) 2>/dev/null
		if test $? -ne 0
		then
			echo ""
			echo "You do not have write permission in ${TARGET}."
			echo "Change the permissions, or select another directory, and try again."
			echo ""
			flag=1
		else
			/bin/rm -f ${TARGET}/${TESTFILE}
		fi
	fi
done

flag=1
while test ${flag} -eq 1
do
	echo ""
	echo "Please specify a socket port number that Aglets server will use."
	echo "If you want to run Aglets server as an user process, you should choose"
	echo "a number which is greater than 1024."
	echo "We recommend you to use 434 or 4434."
	echo ""
	${ECHO} "Socket port number [4434] ${ENDER}"
	read d
	if test -z "${d}"; then
		d=4434
	fi
	if test ${d} -gt 0; then
		DEF_PORT=${d}
		flag=0
	else
		echo "Invalid port number.  It must be a positive number."
	fi
done

#
# Choose installation packages.
#
echo ""
echo "There are some sub-packages in this package."
echo "You can choose a installation set."
echo ""
echo "1. Normal  ... Runtime + documents + samples."
echo "2. All     ... Normal + aglets source."
echo "3. Minimal ... Only runtime."
echo ""
flag=1
while test ${flag} -eq 1
do
	${ECHO} "Please specify by number (1-3)[1] ${ENDER}"
	read check
	flag=0
	if test "${check}" = "2"
	then
		runtime=1
		doc=1
		src=1
	elif test "${check}" = "3"
	then
		runtime=1
		doc=0
		src=0
	elif test -z "${check}" -o "${check}" = "1"
	then
		runtime=1
		doc=1
		src=0
	else
		echo ""
		flag=1
	fi
done

#
# Begin installation.
#
echo ""
echo ""
echo "Installing files..."

#
# Keep a log of this installation for reference.
#
LOGFILE="install.log-$$"
date > ${LOGFILE}
echo "Files installed:" >> ${LOGFILE}
echo "================" >> ${LOGFILE}

#
# 
#
#${UC} -c main.tgz | (cd ${TARGET}; tar xvf - ) >> ${LOGFILE}
#cp ReadMe.txt $TARGET/

for i in runtime doc src
do
	tmp=$"$i"
	eval tmp=$tmp

	if test $tmp = 1
	then
		${UC} -c ${i}.tar.Z | ( cd ${TARGET}; tar xvf - ) >> ${LOGFILE}
	fi
done

#
# Modify agletsd script
#
if test $runtime = 1
then
	tmp=/tmp/asdkinstall.$$
	sed -e "s:#@@@AGLET_HOME@@@:AGLET_HOME=${TARGET}; export AGLET_HOME:" \
		-e "s:#@@@JDK_HOME@@@:JDK_HOME=${JDK_HOME}:" \
		-e "s:#@@@DEF_PORT@@@:DEF_PORT=${DEF_PORT}:" \
	   ${TARGET}/bin/agletsd > $tmp
	rm -f ${TARGET}/bin/agletsd
	cp $tmp ${TARGET}/bin/agletsd
	rm -f $tmp
	chmod +x ${TARGET}/bin/agletsd
	chmod +x ${TARGET}/bin/openurl
fi

#
#
echo ""
echo "Installation completed."
echo "Please read ${TARGET}/ReadMe.txt"
